@@ -29,7 +29,7 @@ from gtdb_validation_tk.common import (placeholder_genus,
                                         latinized_specific_sp_name)
 
 
-class CheckTaxonomyFile():
+class CheckTaxonomyFile(object):
     """Validate different aspects of standard taxonomy file."""
 
     def __init__(self, dpi=96):
