@@ -689,6 +689,7 @@ class OptionsParser(object):
     def add_dummy(self, options):
         """Add a zero branch length sister node to each current leaf node."""
 
+        # add dummy nodes to tree
         check_file_exists(options.input_tree)
 
         self.logger.info('Reading input tree.')
@@ -712,14 +713,34 @@ class OptionsParser(object):
                            edge_length=0.0)
 
         # write new tree to file
+        base, ext = os.path.splitext(options.input_tree)
+        output_tree = base + '.dummy_nodes' + ext
         self.logger.info(
-            'Writing modified tree to: {}'.format(options.output_tree))
-        tree.write_to_path(options.output_tree,
+            'Writing modified tree to: {}'.format(output_tree))
+        tree.write_to_path(output_tree,
                            schema='newick',
                            suppress_rooting=True,
                            suppress_leaf_node_labels=False,
                            unquoted_underscores=True)
 
+        # add dummy nodes to taxonomy file
+        if options.taxonomy_file:
+            self.logger.info('Adding dummy nodes to taxonomy file.')
+            
+            base, ext = os.path.splitext(options.taxonomy_file)
+            output_taxonomy_file = base + '.dummy_nodes' + ext
+            fout = open(output_taxonomy_file, 'w')
+            
+            with open(options.taxonomy_file) as f:
+                for line in f:
+                    fout.write(line)
+                    fout.write('D-'+line)
+          
+            fout.close()
+            
+            self.logger.info(
+            'Writing modified taxonomy file to: {}'.format(output_taxonomy_file))
+
         self.logger.info('Done.')
 
     def remove_dummy(self, options):
