@@ -27,7 +27,7 @@ from biolib.taxonomy import Taxonomy
 import dendropy
 
 
-class MissingGenera():
+class MissingGenera(object):
     """Report lineages that may represent missing genus names."""
 
     def __init__(self, dpi=96):
@@ -73,7 +73,7 @@ class MissingGenera():
         fout.write('Taxonomy\tGenus\tGenome IDs\tRED of node\tRED of node - RED genus median\n')
         self.logger.info('Identifying internal nodes that may be missing a genus label.')
         s = [tree.seed_node]
-        while(s):
+        while s:
             n = s.pop()
             
             # process node
